@@ -21,21 +21,28 @@ class TestStepMetadata(unittest.TestCase):
             "habituation_total": 0,
             "last_preview_phase_step": 0,
             "last_step": null,
-            "metadata": {}
+            "metadata": {},
+            "steps_allowed_in_lava": 0
         },
         "habituation_trial": null,
+        "haptic_feedback": {},
         "head_tilt": 0.0,
+        "holes": [],
         "image_list": [],
+        "lava": [],
         "object_list": [],
         "object_mask_list": [],
         "performer_radius": 0.0,
         "performer_reach": 0.0,
         "physics_frames_per_second": 0,
         "position": {},
+        "resolved_object": "",
+        "resolved_receptacle": "",
         "return_status": "UNDEFINED",
         "reward": 0,
         "rotation": 0.0,
         "step_number": 0,
+        "steps_on_lava": 0,
         "structural_object_list": []
     }'''
 
@@ -53,21 +60,28 @@ class TestStepMetadata(unittest.TestCase):
             "habituation_total": 0,
             "last_preview_phase_step": 0,
             "last_step": null,
-            "metadata": {}
+            "metadata": {},
+            "steps_allowed_in_lava": 0
         },
         "habituation_trial": null,
+        "haptic_feedback": {},
         "head_tilt": 0.0,
+        "holes": [],
         "image_list": [],
+        "lava": [],
         "object_list": [],
         "object_mask_list": [],
         "performer_radius": 0.0,
         "performer_reach": 0.0,
         "physics_frames_per_second": 0,
         "position": {},
+        "resolved_object": "",
+        "resolved_receptacle": "",
         "return_status": "UNDEFINED",
         "reward": 0,
         "rotation": 0.0,
         "step_number": 0,
+        "steps_on_lava": 0,
         "structural_object_list": [],
         "segment_map": {
             "0": {
@@ -118,10 +132,18 @@ class TestStepMetadata(unittest.TestCase):
         self.assertAlmostEqual(self.step_metadata.head_tilt, 0.0)
         self.assertIsInstance(self.step_metadata.head_tilt, float)
 
+    def test_holes(self):
+        self.assertEqual(self.step_metadata.holes, [])
+        self.assertIsInstance(self.step_metadata.holes, list)
+
     def test_image_list(self):
         self.assertFalse(self.step_metadata.image_list)
         self.assertIsInstance(self.step_metadata.image_list, list)
 
+    def test_lava(self):
+        self.assertEqual(self.step_metadata.lava, [])
+        self.assertIsInstance(self.step_metadata.lava, list)
+
     def test_object_list(self):
         self.assertFalse(self.step_metadata.object_list)
         self.assertIsInstance(self.step_metadata.object_list, list)
@@ -141,6 +163,40 @@ class TestStepMetadata(unittest.TestCase):
     def test_position(self):
         self.assertIsInstance(self.step_metadata.position, dict)
 
+    def test_resolved_object(self):
+        self.assertEqual(self.step_metadata.resolved_object, '')
+        self.assertIsInstance(self.step_metadata.resolved_object, str)
+
+        self.step_metadata.resolved_object = 'testResolvedId'
+        self.assertEqual(self.step_metadata.resolved_object, 'testResolvedId')
+        self.assertIsInstance(self.step_metadata.resolved_object, str)
+
+        self.step_metadata.resolved_object = 'testResolved'
+        self.assertNotEqual(
+            self.step_metadata.resolved_object,
+            'testResolvedId')
+        self.assertIsInstance(self.step_metadata.resolved_object, str)
+
+        self.step_metadata.resolved_object = ''
+
+    def test_resolved_receptacle(self):
+        self.assertEqual(self.step_metadata.resolved_receptacle, '')
+        self.assertIsInstance(self.step_metadata.resolved_receptacle, str)
+
+        self.step_metadata.resolved_receptacle = 'testResolvedId'
+        self.assertEqual(
+            self.step_metadata.resolved_receptacle,
+            'testResolvedId')
+        self.assertIsInstance(self.step_metadata.resolved_receptacle, str)
+
+        self.step_metadata.resolved_receptacle = 'testResolved'
+        self.assertNotEqual(
+            self.step_metadata.resolved_receptacle,
+            'testResolvedId')
+        self.assertIsInstance(self.step_metadata.resolved_receptacle, str)
+
+        self.step_metadata.resolved_receptacle = ''
+
     def test_return_status(self):
         self.assertEqual(
             self.step_metadata.return_status,
@@ -202,6 +258,8 @@ class TestStepMetadata(unittest.TestCase):
             physics_frames_per_second=20,
             position={'x': 1, 'z': 2},
             return_status=mcs.ReturnStatus.SUCCESSFUL.value,
+            resolved_object='testObjectId',
+            resolved_receptacle='',
             reward=0,
             rotation=90,
             step_number=25,
@@ -238,6 +296,8 @@ class TestStepMetadata(unittest.TestCase):
         )
         self.assertEqual(data.position, copy.position)
         self.assertEqual(data.return_status, copy.return_status)
+        self.assertEqual(data.resolved_object, copy.resolved_object)
+        self.assertEqual(data.resolved_receptacle, copy.resolved_receptacle)
         self.assertEqual(data.reward, copy.reward)
         self.assertEqual(data.rotation, copy.rotation)
         self.assertEqual(data.step_number, copy.step_number)
